@@ -403,15 +403,14 @@ sub AUTOLOAD  {
   
   no strict 'refs';
 
-  if ($AUTOLOAD =~ /.*::(\w+)/ &&  $self->_Accessible($1,'read') )  {
+  if ($AUTOLOAD =~ /.*::(\w+)/o &&  $self->_Accessible($1,'read') )  {
     my $Attrib = $1;
 
     *{$AUTOLOAD} = sub { return ($_[0]->_Value($Attrib))};
     return($self->_Value($Attrib));
   }
     
-  elsif ( ($AUTOLOAD =~ /.*::Set(\w+)/ or
-           $AUTOLOAD =~ /.*::set_(\w+)/ ) ) {
+  elsif ($AUTOLOAD =~ /.*::[sS]et_?(\w+)/o) {
 
     if ($self->_Accessible($1,'write')) {
       my $Attrib = $1;
@@ -439,7 +438,7 @@ sub AUTOLOAD  {
   #right idea. it breaks the ability to do ValidateQueue for a ticket
   #on creation.
 
-  elsif ($AUTOLOAD =~ /.*::Validate(\w+)/ ) {
+  elsif ($AUTOLOAD =~ /.*::[vV]alidate_?(\w+)/o ) {
     my $Attrib = $1;
 
     *{$AUTOLOAD} = sub {  return ($_[0]->_Validate($Attrib, $_[1]))};
@@ -848,7 +847,7 @@ sub LoadFromHash {
   my $hashref = shift;
   
   $self->{'values'} = $hashref;
-  $self->_DowncaseValuesHash();
+  #$self->_DowncaseValuesHash();
   return ($self->{'values'}{'id'});
 }
 
@@ -884,7 +883,7 @@ sub _LoadFromSQL {
         return ( 0, "Couldn't find row" );
     }
 
-    $self->_DowncaseValuesHash();
+    #$self->_DowncaseValuesHash();
 
     ## I guess to be consistant with the old code, make sure the primary  
     ## keys exist.
@@ -925,7 +924,7 @@ sub _LoadFromSQLold {
 
     ## I guess to be consistant with the old code, make sure the primary  
     ## keys exist.
-      $self->_DowncaseValuesHash();
+      #$self->_DowncaseValuesHash();
     
         ## I guess to be consistant with the old code, make sure the primary  
         ## keys exist.
