@@ -6,7 +6,7 @@
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
-BEGIN { $| = 1; print "1..7\n"; }
+BEGIN { $| = 1; print "1..6\n"; }
 END {print "not ok 1\n" unless $loaded;}
 use DBIx::SearchBuilder;
 $loaded = 1;
@@ -26,9 +26,6 @@ print "ok 5\n";
 use DBIx::SearchBuilder::Handle::Oracle;
 $oracle =1;
 print "ok 6\n";
-use DBIx::SearchBuilder::Handle::ODBC;
-$obdc =1;
-print "ok 7\n";
 ######################### End of black magic.
 
 # Insert your test code below (better if it prints "ok 13"
